@@ -17,8 +17,8 @@
  *
  * <b>Dispatcher Prototype</b>
  * \code
- * void volk_32fc_x2_s32f_square_dist_scalar_mult_32f(float* target, lv_32fc_t* src0,
- * lv_32fc_t* points, float scalar, unsigned int num_points) \endcode
+ * void volk_32fc_x2_s32f_square_dist_scalar_mult_32f(float* target, const lv_32fc_t*
+ * src0, const lv_32fc_t* points, float scalar, unsigned int num_points) \endcode
  *
  * \b Inputs
  * \li src0: The complex input. Only the first point is used.
@@ -94,8 +94,8 @@ static inline void calculate_scaled_distances(float* target,
 
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_avx2(float* target,
-                                                     lv_32fc_t* src0,
-                                                     lv_32fc_t* points,
+                                                     const lv_32fc_t* src0,
+                                                     const lv_32fc_t* points,
                                                      float scalar,
                                                      unsigned int num_points)
 {
@@ -178,8 +178,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_avx2(float* target,
 
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_avx(float* target,
-                                                    lv_32fc_t* src0,
-                                                    lv_32fc_t* points,
+                                                    const lv_32fc_t* src0,
+                                                    const lv_32fc_t* points,
                                                     float scalar,
                                                     unsigned int num_points)
 {
@@ -219,8 +219,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_avx(float* target,
 
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_sse3(float* target,
-                                                     lv_32fc_t* src0,
-                                                     lv_32fc_t* points,
+                                                     const lv_32fc_t* src0,
+                                                     const lv_32fc_t* points,
                                                      float scalar,
                                                      unsigned int num_points)
 {
@@ -278,8 +278,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_sse3(float* target,
 #include <xmmintrin.h>
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_sse(float* target,
-                                                    lv_32fc_t* src0,
-                                                    lv_32fc_t* points,
+                                                    const lv_32fc_t* src0,
+                                                    const lv_32fc_t* points,
                                                     float scalar,
                                                     unsigned int num_points)
 {
@@ -303,8 +303,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_a_sse(float* target,
 #ifdef LV_HAVE_GENERIC
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_generic(float* target,
-                                                      lv_32fc_t* src0,
-                                                      lv_32fc_t* points,
+                                                      const lv_32fc_t* src0,
+                                                      const lv_32fc_t* points,
                                                       float scalar,
                                                       unsigned int num_points)
 {
@@ -329,8 +329,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_generic(float* target,
 
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_avx2(float* target,
-                                                     lv_32fc_t* src0,
-                                                     lv_32fc_t* points,
+                                                     const lv_32fc_t* src0,
+                                                     const lv_32fc_t* points,
                                                      float scalar,
                                                      unsigned int num_points)
 {
@@ -413,8 +413,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_avx2(float* target,
 
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_avx(float* target,
-                                                    lv_32fc_t* src0,
-                                                    lv_32fc_t* points,
+                                                    const lv_32fc_t* src0,
+                                                    const lv_32fc_t* points,
                                                     float scalar,
                                                     unsigned int num_points)
 {
@@ -454,8 +454,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_avx(float* target,
 
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_sse3(float* target,
-                                                     lv_32fc_t* src0,
-                                                     lv_32fc_t* points,
+                                                     const lv_32fc_t* src0,
+                                                     const lv_32fc_t* points,
                                                      float scalar,
                                                      unsigned int num_points)
 {
@@ -513,8 +513,8 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_sse3(float* target,
 #include <xmmintrin.h>
 static inline void
 volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_sse(float* target,
-                                                    lv_32fc_t* src0,
-                                                    lv_32fc_t* points,
+                                                    const lv_32fc_t* src0,
+                                                    const lv_32fc_t* points,
                                                     float scalar,
                                                     unsigned int num_points)
 {
@@ -535,4 +535,62 @@ volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_sse(float* target,
 }
 #endif // LV_HAVE_SSE
 
+#ifdef LV_HAVE_RVV
+#include <riscv_vector.h>
+
+static inline void
+volk_32fc_x2_s32f_square_dist_scalar_mult_32f_rvv(float* target,
+                                                  const lv_32fc_t* src0,
+                                                  const lv_32fc_t* points,
+                                                  float scalar,
+                                                  unsigned int num_points)
+{
+    size_t vlmax = __riscv_vsetvlmax_e32m4();
+    vfloat32m4_t var = __riscv_vfmv_v_f_f32m4(lv_creal(*src0), vlmax);
+    vfloat32m4_t vai = __riscv_vfmv_v_f_f32m4(lv_cimag(*src0), vlmax);
+    vfloat32m4_t vscale = __riscv_vfmv_v_f_f32m4(scalar, vlmax);
+
+    size_t n = num_points;
+    for (size_t vl; n > 0; n -= vl, target += vl, points += vl) {
+        vl = __riscv_vsetvl_e32m4(n);
+        vuint64m8_t vb = __riscv_vle64_v_u64m8((const uint64_t*)points, vl);
+        vfloat32m4_t vbr = __riscv_vreinterpret_f32m4(__riscv_vnsrl(vb, 0, vl));
+        vfloat32m4_t vbi = __riscv_vreinterpret_f32m4(__riscv_vnsrl(vb, 32, vl));
+        vfloat32m4_t vr = __riscv_vfsub(var, vbr, vl);
+        vfloat32m4_t vi = __riscv_vfsub(vai, vbi, vl);
+        vfloat32m4_t v = __riscv_vfmacc(__riscv_vfmul(vi, vi, vl), vr, vr, vl);
+        __riscv_vse32(target, __riscv_vfmul(v, vscale, vl), vl);
+    }
+}
+#endif /*LV_HAVE_RVV*/
+
+#ifdef LV_HAVE_RVVSEG
+#include <riscv_vector.h>
+
+static inline void
+volk_32fc_x2_s32f_square_dist_scalar_mult_32f_rvvseg(float* target,
+                                                     const lv_32fc_t* src0,
+                                                     const lv_32fc_t* points,
+                                                     float scalar,
+                                                     unsigned int num_points)
+{
+    size_t vlmax = __riscv_vsetvlmax_e32m4();
+    vfloat32m4_t var = __riscv_vfmv_v_f_f32m4(lv_creal(*src0), vlmax);
+    vfloat32m4_t vai = __riscv_vfmv_v_f_f32m4(lv_cimag(*src0), vlmax);
+    vfloat32m4_t vscale = __riscv_vfmv_v_f_f32m4(scalar, vlmax);
+
+    size_t n = num_points;
+    for (size_t vl; n > 0; n -= vl, target += vl, points += vl) {
+        vl = __riscv_vsetvl_e32m4(n);
+        vfloat32m4x2_t vb = __riscv_vlseg2e32_v_f32m4x2((const float*)points, vl);
+        vfloat32m4_t vbr = __riscv_vget_f32m4(vb, 0);
+        vfloat32m4_t vbi = __riscv_vget_f32m4(vb, 1);
+        vfloat32m4_t vr = __riscv_vfsub(var, vbr, vl);
+        vfloat32m4_t vi = __riscv_vfsub(vai, vbi, vl);
+        vfloat32m4_t v = __riscv_vfmacc(__riscv_vfmul(vi, vi, vl), vr, vr, vl);
+        __riscv_vse32(target, __riscv_vfmul(v, vscale, vl), vl);
+    }
+}
+#endif /*LV_HAVE_RVVSEG*/
+
 #endif /*INCLUDED_volk_32fc_x2_s32f_square_dist_scalar_mult_32f_u_H*/
